==> openssl_encrypt-0.8.2.tar.gz: openssl_encrypt-0.8.2/tests/dual_encryption/test_dual_encryption_keystore.py <==
#!/usr/bin/env python3
"""
Test for PQC dual encryption with keystore integration
"""

import os
import sys
import tempfile
import unittest
import shutil
import base64
import json
import getpass
import uuid
from unittest.mock import patch, Mock

# Add parent directory to path for importing
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

# Import from the package
from openssl_encrypt.modules.crypt_core import encrypt_file, decrypt_file
from openssl_encrypt.modules.keystore_cli import PQCKeystore

# Because the encrypt_file and decrypt_file functions have been modified to use 'args',
# we need to patch the functions to work with our tests
class TestPQCDualEncryptionWithKeystore(unittest.TestCase):
    """Test cases for PQC dual encryption with keystore integration"""
    
    def setUp(self):
        """Set up test environment before each test"""
        # Create temporary directory for test files
        self.temp_dir = tempfile.mkdtemp()
        
        # Create test file paths
        self.input_file = os.path.join(self.temp_dir, 'test_input.txt')
        self.encrypted_file = os.path.join(self.temp_dir, 'test_encrypted.enc')
        self.decrypted_file = os.path.join(self.temp_dir, 'test_decrypted.txt')
        self.keystore_file = os.path.join(self.temp_dir, 'test_keystore.pqc')
        
        # Create a test input file
        with open(self.input_file, 'w') as f:
            f.write('This is a test message for encryption and decryption.')
        
        # Test passwords
        self.keystore_password = 'test_keystore_password'
        self.file_password = 'test_file_password'
    
    def tearDown(self):
        """Clean up test environment after each test"""
        # Remove temporary directory and all files
        shutil.rmtree(self.temp_dir)
    
    @patch('openssl_encrypt.modules.crypt_core.encrypt_file')
    @patch('openssl_encrypt.modules.crypt_core.decrypt_file')
    def test_basic_flow(self, mock_decrypt, mock_encrypt):
        """Test the basic flow - this is just a placeholder since we can't directly test the modified functions"""
        mock_encrypt.return_value = True
        mock_decrypt.return_value = True
        
        # This test just verifies that our test setup is correct
        self.assertTrue(os.path.exists(self.input_file))
        self.assertTrue(mock_encrypt())
        self.assertTrue(mock_decrypt())

    def test_keystore_creation(self):
        """Test creating a keystore and adding a key to it"""
        # Create a new keystore
        keystore = PQCKeystore(self.keystore_file)
        keystore.create_keystore(self.keystore_password)
        
        # Verify the keystore file exists
        self.assertTrue(os.path.exists(self.keystore_file))
        
        # Print keystore data for debugging
        print(f"Keystore created at: {self.keystore_file}")
        
        # Test finished successfully - we won't test actual key operations
        # since they depend on the specific implementation

if __name__ == '__main__':
    unittest.main()

==> openssl_encrypt-1.0.0.tar.gz: openssl_encrypt-1.0.0/tests/dual_encryption/test_dual_encryption_keystore.py <==
#!/usr/bin/env python3
"""
Test for PQC dual encryption with keystore integration
"""

import base64
import getpass
import json
import os
import shutil
import sys
import tempfile
import unittest
import uuid
from unittest.mock import Mock, patch

# Add parent directory to path for importing
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))

# Import from the package
from openssl_encrypt.modules.crypt_core import decrypt_file, encrypt_file
from openssl_encrypt.modules.keystore_cli import PQCKeystore


# Because the encrypt_file and decrypt_file functions have been modified to use 'args',
# we need to patch the functions to work with our tests
class TestPQCDualEncryptionWithKeystore(unittest.TestCase):
    """Test cases for PQC dual encryption with keystore integration"""

    def setUp(self):
        """Set up test environment before each test"""
        # Create temporary directory for test files
        self.temp_dir = tempfile.mkdtemp()

        # Create test file paths
        self.input_file = os.path.join(self.temp_dir, "test_input.txt")
        self.encrypted_file = os.path.join(self.temp_dir, "test_encrypted.enc")
        self.decrypted_file = os.path.join(self.temp_dir, "test_decrypted.txt")
        self.keystore_file = os.path.join(self.temp_dir, "test_keystore.pqc")

        # Create a test input file
        with open(self.input_file, "w") as f:
            f.write("This is a test message for encryption and decryption.")

        # Test passwords
        self.keystore_password = "test_keystore_password"
        self.file_password = "test_file_password"

    def tearDown(self):
        """Clean up test environment after each test"""
        # Remove temporary directory and all files
        shutil.rmtree(self.temp_dir)

    @patch("openssl_encrypt.modules.crypt_core.encrypt_file")
    @patch("openssl_encrypt.modules.crypt_core.decrypt_file")
    def test_basic_flow(self, mock_decrypt, mock_encrypt):
        """Test the basic flow - this is just a placeholder since we can't directly test the modified functions"""
        mock_encrypt.return_value = True
        mock_decrypt.return_value = True

        # This test just verifies that our test setup is correct
        self.assertTrue(os.path.exists(self.input_file))
        self.assertTrue(mock_encrypt())
        self.assertTrue(mock_decrypt())

    def test_keystore_creation(self):
        """Test creating a keystore and adding a key to it"""
        # Create a new keystore
        keystore = PQCKeystore(self.keystore_file)
        keystore.create_keystore(self.keystore_password)

        # Verify the keystore file exists
        self.assertTrue(os.path.exists(self.keystore_file))

        # Print keystore data for debugging
        print(f"Keystore created at: {self.keystore_file}")

        # Test finished successfully - we won't test actual key operations
        # since they depend on the specific implementation


if __name__ == "__main__":
    unittest.main()
